Constraint
----------


Use Constraint to constrain your models parameters.

.. todo::
    Include more built-in Constraints.

.. autosummary::
    :toctree: _generated/constraint

    zfit.constraint.SimpleConstraint
    zfit.constraint.GaussianConstraint
    zfit.constraint.nll_gaussian
